@@ -1,13 +1,13 @@
-# $Id: Charcount.pm,v 0.06 2004/01/21 17:34:49 sts Exp $
+# $Id: Charcount.pm,v 0.07 2004/01/21 17:34:49 sts Exp $
 
 package String::Charcount;
 
 use 5.006;
 use base qw(Exporter);
-use strict;
+use strict 'vars';
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our (@EXPORT_OK, %EXPORT_TAGS, @subs);
 
@@ -32,10 +32,10 @@ String::Charcount - count the occurence of characters within a string.
 
  $string = 'The lazy brown fox jumped over the cat sitting on the fence.';
 
- $count = count(\$string);
+ $count = count($string);
  print 'e exists ', $$count{e}, ' times',"\n";
 
- $percentage = percentage(\$string, $count);
+ $percentage = percentage($string, $count);
  print 'e percentage - ', $$percentage{e}, '%',"\n";
 
 =head1 DESCRIPTION
@@ -49,7 +49,7 @@ calculates percentage of occurence.
 
 Counts the occurence of all characters within a string.
 
- $count = count(\$string);
+ $count = count($string);
  print 'e exists ', $$count{e}, ' times',"\n";
 
 Returns an hashref with characters as keys and 
@@ -58,12 +58,11 @@ occurences as values.
 =cut
 
 sub count {
-    my $string = $_[0];
-    croak q~usage: count (\$string)~
-      unless $$string && ref $string eq 'SCALAR';
+    my $string = shift;
+    croak q~Usage: count($string)~ unless $string;
       
     my %count;
-    for (split '', $$string) { $count{$_}++ }
+    for (split '', $string) { $count{$_}++ }
     
     return \%count;
 }
@@ -72,20 +71,19 @@ sub count {
 
 Counts unique characters (case-sensitive) within a string.
 
- $unique = count_unique(\$string);
+ $unique = count_unique($string);
  
 Returns a string.
 
 =cut
 
 sub count_unique {
-    my $string = $_[0];
-    croak q~usage: count_unique (\$string)~
-      unless $$string && ref $string eq 'SCALAR'; 
+    my $string = shift;
+    croak q~Usage: count_unique($string)~ unless $string; 
     
     my %count;
-    for my $i (0..(length ($$string) - 1)) {
-        $count{substr $$string, $i, 1}++;
+    for (0..(length($string) - 1)) {
+        $count{substr $string, $_, 1}++;
     }
     
     return scalar keys %count;
@@ -96,7 +94,7 @@ sub count_unique {
 Calculates percentage of occurence of 
 all characters within a string.
 
- $percentage = percentage(\$string, $count);
+ $percentage = percentage($string, [$count]);
  print 'e percentage - ', $$percentage{e}, '%',"\n";
 
 Returns an hashref with characters as keys and 
@@ -105,16 +103,16 @@ percentages of occurence as values.
 =cut
 
 sub percentage {
-    my ($string, $count) = @_;
-    croak q~usage: percentage (\$string, $count_ref)~
-      unless $$string && %$count 
-      && ref $string eq 'SCALAR' && ref $count eq 'HASH';
+    my $string = shift;
+    my %count  = %{'shift'} || %{count($string)}; 
+    croak q~Usage: percentage($string, [$countref])~
+      unless $string;
        
-    my $perc_single = 100 / length $$string;
+    my $perc_single = 100 / length $string;
     
     my %percentage;
-    for (keys %$count) {
-        $percentage{$_} = sprintf "%2.2f", $$count{$_} * $perc_single;
+    for (keys %count) {
+        $percentage{$_} = sprintf "%2.2f", $count{$_} * $perc_single;
     }
           
     return \%percentage;
